   #include <stdio.h>
#include <stdbool.h>
#include <nrf51.h>
#include "twi_master.h"
#include <stdint.h>
#include "nrf.h"
#include "nrf_gpio.h"
#include "app_timer.h"
#include "app_button.h"
#include "app_gpiote.h"
#define APP_TIMER_PRESCALER               			0                                                 /**< Value of the RTC1 PRESCALER register. */
#define APP_TIMER_MAX_TIMERS              			5                                                 /**< Maximum number of simultaneously created timers. 1 for Battery measurement, 2 for flashing Advertising LED and Alert LED, 1 for connection parameters module, 1 for button polling timer needed by the app_button module,  */
#define APP_TIMER_OP_QUEUE_SIZE           			6                                                 /**< Size of timer operation queues. */

#define SEND_TO_BLE_STACK_FOR_EVERY_2hours      APP_TIMER_TICKS(1000, APP_TIMER_PRESCALER)
#define BUTTON_DETECTION_DELAY            			APP_TIMER_TICKS(50, APP_TIMER_PRESCALER)          /**< Delay from a GPIOTE event until a button is reported as pushed (in number of timer ticks). */

#define APP_GPIOTE_MAX_USERS              1                                                 /**< Maximum number of users of the GPIOTE handler. */

	static app_timer_id_t                  				  m_ble_stack_timer_id;                               /**< Battery measurement timer. */

	int i=0;
	uint8_t  seconds=0;
	uint8_t  minits=0;
	uint8_t  hours=0;
	
	
	static void ble_stack_level_meas_timeout_handler(void * p_context)
	{
	 //   UNUSED_PARAMETER(p_context);
		//	i=~i;
		  NRF_GPIO->OUTSET=(1<<18);
		for(i=0;i<0xff;i++);
		NRF_GPIO->OUTCLR=(1<<18);
	}
		/*seconds++;
		if(seconds==60)
		{
			minits++;
			seconds=0;
		}
		if(minits==60)
		{
			hours=1;
			seconds=0;
			minits=0;
		}*/
	static void timers_init(void)
	{
			uint32_t err_code;

			// Initialize timer module
			APP_TIMER_INIT(APP_TIMER_PRESCALER, APP_TIMER_MAX_TIMERS, APP_TIMER_OP_QUEUE_SIZE, false);

			// Create battery timer
			err_code = app_timer_create(&m_ble_stack_timer_id,
																	APP_TIMER_MODE_REPEATED,
																	ble_stack_level_meas_timeout_handler);
			APP_ERROR_CHECK(err_code);
			
			//err_code = app_timer_start(m_ble_stack_timer_id, SEND_TO_BLE_STACK_FOR_EVERY_2hours, NULL);
			//APP_ERROR_CHECK(err_code);
		/*  err_code = app_timer_create(&m_alert_led_blink_timer_id,
																	APP_TIMER_MODE_SINGLE_SHOT,
																	mild_alert_timeout_handler);
			APP_ERROR_CHECK(err_code);

			err_code = app_timer_create(&m_adv_led_blink_timer_id,
																	APP_TIMER_MODE_SINGLE_SHOT,
																	adv_led_blink_timeout_handler);
			APP_ERROR_CHECK(err_code);*/
}
static void button_event_handler(uint8_t pin_no)
{
    uint32_t err_code;

    switch (pin_no)
    {
        case 16:
							NRF_GPIO->OUTSET=(1<<19);
						
            break;

        case 17:
						NRF_GPIO->OUTCLR=(1<<19);
				
            break;

        default:
            APP_ERROR_HANDLER(pin_no);
    }
}


void assert_nrf_callback(uint16_t line_num, const uint8_t * p_file_name)
{
    app_error_handler(0xDEADBEEF, line_num, p_file_name);
}




void app_error_handler(uint32_t error_code, uint32_t line_num, const uint8_t * p_file_name)
{
    // This call can be used for debug purposes during development of an application.
    // @note CAUTION: Activating this code will write the stack to flash on an error.
    //                This function should NOT be used in a final product.
    //                It is intended STRICTLY for development/debugging purposes.
    //                The flash write will happen EVEN if the radio is active, thus interrupting
    //                any communication.
    //                Use with care. Un-comment the line below to use.
    // ble_debug_assert_handler(error_code, line_num, p_file_name);

    // On assert, the system can only recover with a reset.
    NVIC_SystemReset();
}


static void gpiote_init(void)
{
    APP_GPIOTE_INIT(APP_GPIOTE_MAX_USERS);
}

static void buttons_init(void)
{
    static app_button_cfg_t buttons[] =
    {
        {16,  false, NRF_GPIO_PIN_PULLUP, button_event_handler},
        {17, false, NRF_GPIO_PIN_PULLUP, button_event_handler}
    };
    
    APP_BUTTON_INIT(buttons, sizeof(buttons) / sizeof(buttons[0]), BUTTON_DETECTION_DELAY, false);
}




int main()
	{
		uint32_t err_code;
		NRF_GPIO->PIN_CNF[18]=1;
		NRF_GPIO->PIN_CNF[19]=1;
		NRF_CLOCK->TASKS_LFCLKSTART = 1;
    while (NRF_CLOCK->EVENTS_LFCLKSTARTED == 0)
    {
		}
    timers_init();
		 err_code = app_timer_start(m_ble_stack_timer_id, SEND_TO_BLE_STACK_FOR_EVERY_2hours, NULL);
            APP_ERROR_CHECK(err_code);
		gpiote_init();
		buttons_init();
		
		while(1)
		{
		}
	}
